@@ -8,7 +8,7 @@ Do not add this file to the repository.
 import datetime
 
 version = '1.11'
-date = 'Sun Jan 31 00:43:59 2016'
+date = 'Sat Jan  7 07:55:18 2017'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
@@ -18,7 +18,7 @@ dev = False
 version_info = ('networkx', '1', '11', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2016, 1, 31, 0, 43, 59, 84262)
+date_info = datetime.datetime(2017, 1, 7, 7, 55, 18, 119120)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
